from setuptools import setup, find_packages

setup(
    name="labulac",
    version="0.1.1",
    keywords=("pip", "labulac", "labula"),
    description="firs tool",
    long_description="test",
    license="MIT Licence",
    url="https://github.com/labulac/labulac",
    author="cms",
    author_email="740162752@qq.com",
    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=[])
